==> mx-bootrepair_18.12.tar.xz: mx-bootrepair-18.12/translations/mx-bootrepair_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>You must run this program as root.</source>
        <translation>Tento program musíte spustiť ako root užívateľ.</translation>
    </message>
</context>
<context>
    <name>mxbootrepair</name>
    <message>
        <location filename="../mxbootrepair.ui" line="20"/>
        <location filename="../mxbootrepair.cpp" line="445"/>
        <source>MX Boot Repair</source>
        <translation>MX Oprava zavádzača</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="39"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR.</source>
        <translation>MX Oprava zavádzača je program, ktorý môže byť použitý na preinštalovanie GRUB zavádzača do MBR (Master Boot Record) alebo root oddielu. Tiež umožňuje voľbu opravy nastavení GRUBu a  zálohu a obnovenie MBR alebo PBR.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation>Čo si prajete urobiť?</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Zálohovať MBR alebo PBR (iba legacy boot)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="86"/>
        <source>Reinstall GRUB bootloader</source>
        <translation>Preinštalovať zavádzač GRUB</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation>Opraviť konfiguračný súbor GRUBu</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Obnoviť MBR alebo PBR (iba legacy boot)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="123"/>
        <location filename="../mxbootrepair.cpp" line="378"/>
        <source>Select Boot Method</source>
        <translation>Vyberte mód štartu systému</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="141"/>
        <source>Master Boot Record</source>
        <translation>Master Boot Record</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="144"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="147"/>
        <location filename="../mxbootrepair.ui" line="418"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="169"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Root (Partition Boot Record)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="172"/>
        <location filename="../mxbootrepair.cpp" line="380"/>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="223"/>
        <location filename="../mxbootrepair.cpp" line="379"/>
        <source>Install on:</source>
        <translation>Inštalovať do:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="242"/>
        <source>Location:</source>
        <translation>Umiestnenie:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="264"/>
        <source>Select /boot location:</source>
        <translation>Vyberte umiestnenie /boot:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="277"/>
        <source>EFI System Partition</source>
        <translation>Systémový oddiel EFI</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="280"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="407"/>
        <source>About this application</source>
        <translation>O tejto aplikácii</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="410"/>
        <source>About...</source>
        <translation>O Programe</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="460"/>
        <source>Display help </source>
        <translation>Zobraziť nápovedu</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="463"/>
        <source>Help</source>
        <translation>Pomocník</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="471"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="512"/>
        <source>Cancel any changes then quit</source>
        <translation>Zrušit všetky zmeny a ukončiť</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="515"/>
        <location filename="../mxbootrepair.cpp" line="451"/>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="523"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="542"/>
        <source>Apply any changes</source>
        <translation>Použiť všetky zmeny</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="545"/>
        <location filename="../mxbootrepair.cpp" line="78"/>
        <source>Apply</source>
        <translation>Použiť</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="96"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="111"/>
        <location filename="../mxbootrepair.cpp" line="134"/>
        <location filename="../mxbootrepair.cpp" line="164"/>
        <location filename="../mxbootrepair.cpp" line="266"/>
        <location filename="../mxbootrepair.cpp" line="300"/>
        <location filename="../mxbootrepair.cpp" line="418"/>
        <location filename="../mxbootrepair.cpp" line="425"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="112"/>
        <source>Could not mount </source>
        <translation>Nejde pripojiť</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="112"/>
        <source> on /boot/efi</source>
        <translation> na /boot/efi</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="135"/>
        <location filename="../mxbootrepair.cpp" line="165"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>Nebolo možné nastaviť chroot environment.
Prosím prekontrolujte zvolené umiestnenie.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="152"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="186"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="241"/>
        <source>Warning</source>
        <translation>Upozornenie</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source>You are going to write the content of </source>
        <translation>Chystáte sa zapísať obsah</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source> to </source>
        <translation>do</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source>

Are you sure?</source>
        <translation>

Určite?</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="243"/>
        <location filename="../mxbootrepair.cpp" line="296"/>
        <source>Yes</source>
        <translation>Ano</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="243"/>
        <location filename="../mxbootrepair.cpp" line="296"/>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="247"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="267"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation> Nenájdený oddiel EFI, systemový diskový oddiel (ESP) na systemových diskoch. Prosím vytvorte ESP a skúste to znovu.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="294"/>
        <source>Success</source>
        <translation>Úspech</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="295"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>Proces bol úspešne dokončený.&lt;p&gt;&lt;b&gt;Ukončiť MX Oprava zavádzača?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="301"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Proces dokončený. Objavili sa chyby.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="303"/>
        <source>Back</source>
        <translation>Naspäť</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="387"/>
        <source>Select GRUB location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="398"/>
        <source>Select Item to Back Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="405"/>
        <source>Select Item to Restore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="416"/>
        <source>Select backup file name</source>
        <translation>Zvoľte názov záložného súboru</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="418"/>
        <location filename="../mxbootrepair.cpp" line="425"/>
        <source>No file was selected.</source>
        <translation>Nebol vybraný žiadny súbor.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="423"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Zvoľte názov záložného súboru pre MBR alebo PBR</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="444"/>
        <source>About MX Boot Repair</source>
        <translation>O programe MX Oprava zavádzača</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="445"/>
        <source>Version: </source>
        <translation>Verzia:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="447"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Jednoduchá oprava zavádzača pre MX linux</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="448"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="449"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="450"/>
        <source>Changelog</source>
        <translation>História zmien</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="472"/>
        <source>&amp;Close</source>
        <translation>&amp;Zatvoriť</translation>
    </message>
</context>
</TS>

==> mx-bootrepair_19.1.tar.xz: mx-bootrepair-19.1/translations/mx-bootrepair_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>You must run this program as root.</source>
        <translation>Tento program musíte spustiť ako root užívateľ.</translation>
    </message>
</context>
<context>
    <name>mxbootrepair</name>
    <message>
        <location filename="../mxbootrepair.ui" line="20"/>
        <location filename="../mxbootrepair.cpp" line="445"/>
        <source>MX Boot Repair</source>
        <translation>MX Oprava zavádzača</translation>
    </message>
    <message>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR.</source>
        <translation type="vanished">MX Oprava zavádzača je program, ktorý môže byť použitý na preinštalovanie GRUB zavádzača do MBR (Master Boot Record) alebo root oddielu. Tiež umožňuje voľbu opravy nastavení GRUBu a  zálohu a obnovenie MBR alebo PBR.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation>Čo si prajete urobiť?</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Zálohovať MBR alebo PBR (iba legacy boot)</translation>
    </message>
    <message>
        <source>Reinstall GRUB bootloader</source>
        <translation type="vanished">Preinštalovať zavádzač GRUB</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="39"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="86"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation>Opraviť konfiguračný súbor GRUBu</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Obnoviť MBR alebo PBR (iba legacy boot)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="123"/>
        <location filename="../mxbootrepair.cpp" line="378"/>
        <source>Select Boot Method</source>
        <translation>Vyberte mód štartu systému</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="141"/>
        <source>Master Boot Record</source>
        <translation>Master Boot Record</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="144"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="147"/>
        <location filename="../mxbootrepair.ui" line="417"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="169"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Root (Partition Boot Record)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="172"/>
        <location filename="../mxbootrepair.cpp" line="380"/>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="223"/>
        <location filename="../mxbootrepair.cpp" line="379"/>
        <source>Install on:</source>
        <translation>Inštalovať do:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="242"/>
        <source>Location:</source>
        <translation>Umiestnenie:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="264"/>
        <source>Select /boot location:</source>
        <translation>Vyberte umiestnenie /boot:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="277"/>
        <source>EFI System Partition</source>
        <translation>Systémový oddiel EFI</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="280"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="407"/>
        <source>About this application</source>
        <translation>O tejto aplikácii</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="410"/>
        <source>About...</source>
        <translation>O Programe</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="459"/>
        <source>Display help </source>
        <translation>Zobraziť nápovedu</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="462"/>
        <source>Help</source>
        <translation>Pomocník</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="469"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="510"/>
        <source>Cancel any changes then quit</source>
        <translation>Zrušit všetky zmeny a ukončiť</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="513"/>
        <location filename="../mxbootrepair.cpp" line="451"/>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="520"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="539"/>
        <source>Apply any changes</source>
        <translation>Použiť všetky zmeny</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="542"/>
        <location filename="../mxbootrepair.cpp" line="78"/>
        <source>Apply</source>
        <translation>Použiť</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="96"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="111"/>
        <location filename="../mxbootrepair.cpp" line="134"/>
        <location filename="../mxbootrepair.cpp" line="164"/>
        <location filename="../mxbootrepair.cpp" line="266"/>
        <location filename="../mxbootrepair.cpp" line="300"/>
        <location filename="../mxbootrepair.cpp" line="418"/>
        <location filename="../mxbootrepair.cpp" line="425"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="112"/>
        <source>Could not mount </source>
        <translation>Nejde pripojiť</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="112"/>
        <source> on /boot/efi</source>
        <translation> na /boot/efi</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="135"/>
        <location filename="../mxbootrepair.cpp" line="165"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>Nebolo možné nastaviť chroot environment.
Prosím prekontrolujte zvolené umiestnenie.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="152"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="186"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="241"/>
        <source>Warning</source>
        <translation>Upozornenie</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source>You are going to write the content of </source>
        <translation>Chystáte sa zapísať obsah</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source> to </source>
        <translation>do</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source>

Are you sure?</source>
        <translation>

Určite?</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="243"/>
        <location filename="../mxbootrepair.cpp" line="296"/>
        <source>Yes</source>
        <translation>Ano</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="243"/>
        <location filename="../mxbootrepair.cpp" line="296"/>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="247"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="267"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation> Nenájdený oddiel EFI, systemový diskový oddiel (ESP) na systemových diskoch. Prosím vytvorte ESP a skúste to znovu.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="294"/>
        <source>Success</source>
        <translation>Úspech</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="295"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>Proces bol úspešne dokončený.&lt;p&gt;&lt;b&gt;Ukončiť MX Oprava zavádzača?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="301"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Proces dokončený. Objavili sa chyby.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="303"/>
        <source>Back</source>
        <translation>Naspäť</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="387"/>
        <source>Select GRUB location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="398"/>
        <source>Select Item to Back Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="405"/>
        <source>Select Item to Restore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="416"/>
        <source>Select backup file name</source>
        <translation>Zvoľte názov záložného súboru</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="418"/>
        <location filename="../mxbootrepair.cpp" line="425"/>
        <source>No file was selected.</source>
        <translation>Nebol vybraný žiadny súbor.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="423"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Zvoľte názov záložného súboru pre MBR alebo PBR</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="444"/>
        <source>About MX Boot Repair</source>
        <translation>O programe MX Oprava zavádzača</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="445"/>
        <source>Version: </source>
        <translation>Verzia:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="447"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Jednoduchá oprava zavádzača pre MX linux</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="448"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="449"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="450"/>
        <source>Changelog</source>
        <translation>História zmien</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="472"/>
        <source>&amp;Close</source>
        <translation>&amp;Zatvoriť</translation>
    </message>
</context>
</TS>
